package com.dcsoft.system.consume.mapper;



import com.dcsoft.system.consume.domain.ConsumeGroupUser;

import java.util.List;

/**
 * 考勤组人员Mapper接口
 *
 * @author dcsoft
 * @date 2023-01-11
 */
public interface ConsumeGroupUserMapper
{
    /**
     * 查询考勤组人员
     *
     * @param groupId 考勤组人员主键
     * @return 考勤组人员
     */
    public ConsumeGroupUser selectConsumeGroupUserByGroupId(Long groupId);

    /**
     * 查询考勤组人员列表
     *
     * @param consumeGroupUser 考勤组人员
     * @return 考勤组人员集合
     */
    public List<ConsumeGroupUser> selectConsumeGroupUserList(ConsumeGroupUser consumeGroupUser);

    /**
     * 新增考勤组人员
     *
     * @param consumeGroupUser 考勤组人员
     * @return 结果
     */
    public int insertConsumeGroupUser(ConsumeGroupUser consumeGroupUser);

    /**
     * 修改考勤组人员
     *
     * @param consumeGroupUser 考勤组人员
     * @return 结果
     */
    public int updateConsumeGroupUser(ConsumeGroupUser consumeGroupUser);

    /**
     * 删除考勤组人员
     *
     * @param groupId 考勤组人员主键
     * @return 结果
     */
    public int deleteConsumeGroupUserByGroupId(Long groupId);

    /**
     * 批量删除考勤组人员
     *
     * @param groupIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteConsumeGroupUserByGroupIds(Long[] groupIds);


    public int batchGroupUser(List<ConsumeGroupUser> consumeGroupUserList);

    /**
     * 删除考勤组人员
     *
     * @param groupId 考勤组人员主键
     * @return 结果
     */
    public int deleteConsumeGroupUserByUserId(Long userId);

}
